@@ -3,8 +3,8 @@
 ###################
 orthobasis.phylo <- function(x=NULL, prox=NULL,
                              method=c("patristic","nNodes","oriAbouheif","Abouheif","sumDD"), a=1){
-    if(!require(phylobase)) stop("phylobase package is not installed")
-    if(!require(ade4)) stop("ade4 package is not installed")
+    ## if(!require(phylobase)) stop("phylobase package is not installed")
+    ## if(!require(ade4)) stop("ade4 package is not installed")
 
     ## handle arguments
     method <- match.arg(method)
